@@ -57,7 +57,7 @@ be created for the lifetime of the spawner.
 use strict;
 use warnings;
 
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 
 use Carp qw/ croak /;
 use Danga::Socket ();
@@ -115,6 +115,11 @@ once.
 
 =back
 
+=item Gearman::WorkerSpawner->gearmand_pid()
+
+Returns the PID of the gearmand which was started up if I<external> was given
+as the C<gearmand> parameter to C<new>, or undef otherwise.
+
 =cut
 
 our $gearmand_spec;
@@ -175,7 +180,7 @@ sub new {
 
 =item $spawner->add_worker(%options)
 
-Add a new worker set to the manager. A new superviser process will be created
+Add a new worker set to the manager. A new supervisor process will be created
 to manage it if one does not already exist for the worker class. Can take the
 following parameters:
 
@@ -389,6 +394,7 @@ requested, its hostspec is returned.
 
 # singleton server object
 my $gearman_server;
+my $gearmand_pid;
 sub gearman_server {
     unless ($gearman_server) {
         if ($gearmand_spec eq 'external') {
@@ -414,6 +420,7 @@ sub gearman_server {
             die "fork failed: $!" unless defined $pid;
             if ($pid) {
                 $gearman_server = ["127.0.0.1:$gearmand_port"];
+                $gearmand_pid = $pid;
                 # don't return until the server is contactable
                 while (1) {
                     last if IO::Socket::INET->new(
@@ -443,6 +450,10 @@ sub gearman_server {
     }
 }
 
+sub gearmand_pid {
+    return $gearmand_pid || undef;
+}
+
 =back
 
 =head1 INTERNAL METHODS
@@ -657,7 +668,9 @@ sub _reap {
 sub _cleanup {
     my $self = shift;
     return if $quitting++;
-    kill 'INT', keys %{ $self->{kids} };
+    my @kids = keys %{ $self->{kids} };
+    push @kids, $gearmand_pid if $gearmand_pid;
+    kill 'INT', @kids;
     exit 0;
 }
 
